package org.zkoss.chart;

import org.zkoss.json.JSONAware;

/**
 * Stop color for linear gradient, radial gradient, and solid gauges.
 * 
 * @author Christopher
 * @since 2.1.0
 */
public class Stop implements JSONAware{

	private Number stop;
	private String color;
	
	/**
	 * Constructs a stop color object.
	 * @param stop value between 0 and 1
	 * @param color any valid color in string format
	 * @see #setStop(Number)
	 * @see #setColor(String)
	 */
	public Stop(Number stop, String color) {
		this.stop = stop;
		this.color = color;
	}
	
	/**
	 * Get the stop value of this stop object.
	 * @return stop the stop number
	 */
	public Number getStop() {
		return stop;
	}
	
	/**
	 * Set the stop value for this stop object.
	 * Value should be in the range of 0 to 1.
	 * @param stop
	 */
	public void setStop(Number stop) {
		this.stop = stop;
	}
	
	/**
	 * Get the color of this stop object.
	 * @return color the color value as String
	 */
	public String getColor() {
		return color;
	}
	
	/**
	 * Set the color value of this stop object.
	 * Can be in any of the following format:
	 * <ol>
	 * <li>"#A4B5D4" - hex color code</li>
	 * <li>"rgb(143, 34, 98)" - rgb color, each from 0-255</li>
	 * <li>"rgba(53, 63, 108, 0.3)" - rgb color with alpha between 0-1</li>
	 * </ol>
	 * @param color any valid color in string format
	 */
	public void setColor(String color) {
		this.color = color;
	}
	
	public String toJSONString() {
		return "[" + stop + ", '" + color + "']";
	}
}
