/* Jitter.java

	Purpose:
		
	Description:
		
	History:
		Thu Nov 28 16:50:13 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;

/**
 * Apply a jitter effect for the rendered markers.
 * When plotting discrete values, a little random noise may help telling the points apart.
 * The jitter setting applies a random displacement of up to n axis units in either direction.
 * So for example on a horizontal X axis, setting the jitter.x to 0.24 will render
 * the point in a random position between 0.24 units to the left and 0.24 units
 * to the right of the true axis position.
 * On a category axis, setting it to 0.5 will fill up the bin and make the data appear continuous.
 *
 * When rendered on top of a box plot or a column series,
 * a jitter value of 0.24 will correspond to the underlying series' default groupPadding and pointPadding settings.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class Jitter extends Optionable {
	private enum Attrs implements PlotAttribute {
		x, y
	}

	/**
	 * Returns the maximal X offset for the random jitter effect.
	 * <p>
	 * Default: 0
	 */
	public Number getX() {
		return getAttr(Attrs.x, 0).asNumber();
	}

	/**
	 * Sets the maximal X offset for the random jitter effect.
	 */
	public void setX(Number x) {
		setAttr(Attrs.x, x);
	}

	/**
	 * Returns the maximal Y offset for the random jitter effect.
	 * <p>
	 * Default: 0
	 */
	public Number getY() {
		return getAttr(Attrs.y, 0).asNumber();
	}

	/**
	 * Sets the maximal Y offset for the random jitter effect.
	 */
	public void setY(Number y) {
		setAttr(Attrs.y, y);
	}
}
