/* VariablePiePlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Tue Dec 03 16:31:30 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for variable pie plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class VariablePiePlotOptions extends PiePlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		maxPointSize, minPointSize, sizeBy, zMax, zMin
	}

	/**
	 * Returns the maximum size of the points' radius related to chart's plotArea.
	 * If a number is set, it applies in pixels.
	 * <p>
	 * Default: "100%"
	 */
	public Object getMaxPointSize() {
		return getAttr(Attrs.maxPointSize, "100%").asValue();
	}

	/**
	 * Sets the maximum size of the points' radius related to chart's plotArea.
	 * If a number is set, it applies in pixels.
	 */
	public void setMaxPointSize(Number maxPointSize) {
		setAttr(Attrs.maxPointSize, maxPointSize);
	}

	/**
	 * Sets the maximum size of the points' radius related to chart's plotArea.
	 */
	public void setMaxPointSize(String maxPointSize) {
		setAttr(Attrs.maxPointSize, maxPointSize);
	}

	/**
	 * Returns the minimum size of the points' radius related to chart's plotArea.
	 * If a number is set, it applies in pixels.
	 * <p>
	 * Default: "10%"
	 */
	public Object getMinPointSize() {
		return getAttr(Attrs.minPointSize, "10%").asValue();
	}

	/**
	 * Sets the minimum size of the points' radius related to chart's plotArea.
	 * If a number is set, it applies in pixels.
	 */
	public void setMinPointSize(Number minPointSize) {
		setAttr(Attrs.minPointSize, minPointSize);
	}

	/**
	 * Sets the minimum size of the points' radius related to chart's plotArea.
	 */
	public void setMinPointSize(String minPointSize) {
		setAttr(Attrs.minPointSize, minPointSize);
	}

	/**
	 * Returns whether the pie slice's value should be represented by the area
	 * or the radius of the slice. Can be either area or radius.
	 * The default, area, corresponds best to the human perception of the size of each pie slice.
	 * <p>
	 * Default: "area"
	 */
	public String getSizeBy() {
		return getAttr(Attrs.sizeBy, "area").asString();
	}

	/**
	 * Sets whether the pie slice's value should be represented by the area
	 * or the radius of the slice. Can be either area or radius.
	 */
	public void setSizeBy(String sizeBy) {
		if (!("area".equals(sizeBy) || "radius".equals(sizeBy)))
			throw new IllegalArgumentException("Unsupported sizeBy: [" + sizeBy + "]");
		setAttr(Attrs.sizeBy, sizeBy);
	}

	/**
	 * Returns the maximum possible z value for the point's radius calculation.
	 * If the point's Z value is bigger than zMax, the slice will be drawn according to the zMax value.
	 * <p>
	 * Default: null
	 */
	public Number getZMax() {
		return getAttr(Attrs.zMax, null).asNumber();
	}

	/**
	 * Sets the maximum possible z value for the point's radius calculation.
	 * If the point's Z value is bigger than zMax, the slice will be drawn according to the zMax value.
	 */
	public void setZMax(Number zMax) {
		setAttr(Attrs.zMax, zMax);
	}

	/**
	 * Returns the minimum possible z value for the point's radius calculation.
	 * If the point's Z value is smaller than zMin, the slice will be drawn according to the zMin value.
	 * <p>
	 * Default: null
	 */
	public Number getZMin() {
		return getAttr(Attrs.zMin, null).asNumber();
	}

	/**
	 * Sets the maximum possible z value for the point's radius calculation.
	 * If the point's Z value is smaller than zMin, the slice will be drawn according to the zMin value.
	 */
	public void setZMin(Number zMin) {
		setAttr(Attrs.zMin, zMin);
	}
}
