/* VectorPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Thu Dec 05 11:11:01 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for vector plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class VectorPlotOptions extends SeriesPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		rotationOrigin,
		vectorLength
	}

	/**
	 * Returns what part of the vector it should be rotated around.
	 * Can be one of start, center and end.
	 * When start, the vectors will start from the given [x, y] position,
	 * and when end the vectors will end in the [x, y] position.
	 * <p>
	 * Default: "center"
	 */
	public String getRotationOrigin() {
		return getAttr(Attrs.rotationOrigin, "center").asString();
	}

	/**
	 * Sets what part of the vector it should be rotated around.
	 * Can be one of start, center and end.
	 * When start, the vectors will start from the given [x, y] position,
	 * and when end the vectors will end in the [x, y] position.
	 */
	public void setRotationOrigin(String rotationOrigin) {
		if (!("start".equals(rotationOrigin) || "center".equals(rotationOrigin) || "end".equals(rotationOrigin)))
			throw new IllegalArgumentException("Unsupported rotationOrigin: [" + rotationOrigin + "]");
		setAttr(Attrs.rotationOrigin, rotationOrigin);
	}

	/**
	 * Returns maximum length of the arrows in the vector plot.
	 * The individual arrow length is computed between 0 and this value.
	 * <p>
	 * Default: 20
	 */
	public Number getVectorLength() {
		return getAttr(Attrs.vectorLength, 20).asNumber();
	}

	/**
	 * Sets maximum length of the arrows in the vector plot.
	 * The individual arrow length is computed between 0 and this value.
	 */
	public void setVectorLength(Number vectorLength) {
		setAttr(Attrs.vectorLength, vectorLength);
	}
}
