/* WordCloudRotation.java

	Purpose:
		
	Description:
		
	History:
		Fri Dec 06 15:45:31 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Rotation options for the words in the wordcloud.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class WordCloudRotation extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		from, orientations, to
	}

	/**
	 * Returns the smallest degree of rotation for a word.
	 * <p>
	 * Default: 0
	 */
	public Number getFrom() {
		return getAttr(Attrs.from, 0).asNumber();
	}

	/**
	 * Sets the smallest degree of rotation for a word.
	 */
	public void setFrom(Number from) {
		setAttr(Attrs.from, from);
	}

	/**
	 * Returns the number of possible orientations for a word, within the range
	 * of {@code from} and {@code to}. Must be a number larger than 0.
	 * <p>
	 * Default: 2
	 */
	public Number getOrientations() {
		return getAttr(Attrs.orientations, 2).asNumber();
	}

	/**
	 * Sets the number of possible orientations for a word, within the range
	 * of {@code from} and {@code to}. Must be a number larger than 0.
	 */
	public void setOrientations(Number orientations) {
		setAttr(Attrs.orientations, orientations);
	}

	/**
	 * Returns the largest degree of rotation for a word.
	 * <p>
	 * Default: 90
	 */
	public Number getTo() {
		return getAttr(Attrs.to, 90).asNumber();
	}

	/**
	 * Sets the largest degree of rotation for a word.
	 */
	public void setTo(Number to) {
		setAttr(Attrs.to, to);
	}
}
